@@ -9,7 +9,7 @@ from warnings import warn
 
 from IPython.utils.shimmodule import ShimModule, ShimWarning
 
-warn("The `IPython.nbconvert` package has been deprecated since IPython 4.0. "
+warn("The `IPython.nbconvert` package has been deprecated. "
      "You should import from nbconvert instead.", ShimWarning)
 
 # Unconditionally insert the shim into sys.modules so that further import calls
