@@ -6,7 +6,7 @@ import sys
 
 from IPython.core.displayhook import DisplayHook
 
-from prompt_toolkit1.layout.utils import token_list_width
+from prompt_toolkit.layout.utils import token_list_width
 
 class Prompts(object):
     def __init__(self, shell):
@@ -63,18 +63,12 @@ class RichPromptDisplayHook(DisplayHook):
     """Subclass of base display hook using coloured prompt"""
     def write_output_prompt(self):
         sys.stdout.write(self.shell.separate_out)
-        # If we're not displaying a prompt, it effectively ends with a newline,
-        # because the output will be left-aligned.
-        self.prompt_end_newline = True
-
+        self.prompt_end_newline = False
         if self.do_full_cache:
             tokens = self.shell.prompts.out_prompt_tokens()
-            prompt_txt = ''.join(s for t, s in tokens)
-            if prompt_txt and not prompt_txt.endswith('\n'):
-                # Ask for a newline before multiline output
-                self.prompt_end_newline = False
-
+            if tokens and tokens[-1][1].endswith('\n'):
+                self.prompt_end_newline = True
             if self.shell.pt_cli:
                 self.shell.pt_cli.print_tokens(tokens)
             else:
-                sys.stdout.write(prompt_txt)
+                print(*(s for t, s in tokens), sep='')
